#include <stdint.h>
#include "SparkFunBME280.h"
#include "Wire.h"

//LED pin assignments
const int RED_PIN = 11; 
const int YLW_PIN = 10;
const int BLUE_PIN = 9;

//Set variable for each Soil moisture sensor
float SM_1;             //Sensor #1
float SM_2;             //Sensor #2
float SM_3;             //Sensor #3

//Global sensor object
BME280 mySensor;
int Soil_sensor_1 = A0;
int Soil_sensor_2 = A1;
int Soil_sensor_3 = A2;
unsigned int sampleNumber = 0; // Counts number of CSV rows

void setup() {

  //LED pin setup
  pinMode(RED_PIN,OUTPUT);                       //Red light lED
  pinMode(YLW_PIN,OUTPUT);                       //Yellow light LED
  pinMode(BLUE_PIN,OUTPUT);                      //Blue light LED
  
    //***Set up sensor 'A'******************************//
  //Here the commInterface was set to I2C mode instead of SPI mode. 
  mySensor.settings.commInterface = I2C_MODE;
  mySensor.settings.I2CAddress = 0x77;
  mySensor.settings.runMode = 3; //  3, Normal mode
  mySensor.settings.tStandby = 0; //  0, 0.5ms
  mySensor.settings.filter = 0; //  0, filter off
  //Temp, pressure, and humidity oversampling. 
  mySensor.settings.tempOverSample = 1;
  mySensor.settings.pressOverSample = 1;
  mySensor.settings.humidOverSample = 1;
 
  //***Initialize all the things**************************//
  Serial.begin(9600);
  Serial.print("Initializing\n");
  Serial.println("Starting BME280");
  delay(10);  //Make sure sensor had enough time to turn on. BME280 requires 2ms to start up.
  //Calling .begin() causes the settings to be loaded
  Serial.print("Sensor: 0x");
  Serial.println(mySensor.begin(), HEX);

  //Build the header
  Serial.print("\n\n");
  Serial.print("Sample,");
  Serial.print("T(deg C),");
  Serial.print("P(Pa),");
  Serial.print("Alt(m),");
  Serial.print("%RH");
  Serial.print("SM_1");
  Serial.print("SM_2");
  Serial.print("SM_3");
  Serial.println("");
}

void loop() {
 
 //Print each row in the loop
  //Start with temperature, as that data is needed for accurate compensation.
  //Reading the temperature updates the compensators of the other functions
  //in the background.

  SM_1 = analogRead(Soil_sensor_1);
  SM_2 = analogRead(Soil_sensor_2);
  SM_3 = analogRead(Soil_sensor_3);

  Serial.print(sampleNumber);
  Serial.print(",");
  Serial.print(mySensor.readTempC(), 2);
  Serial.print(",");
  Serial.print(mySensor.readFloatPressure(), 0);
  Serial.print(",");
  Serial.print(mySensor.readFloatAltitudeMeters(), 3);
  Serial.print(",");
  Serial.print(mySensor.readFloatHumidity(), 0);
  Serial.print(",");
  Serial.print(analogRead(Soil_sensor_1));
  Serial.print(",");
  Serial.print(analogRead(Soil_sensor_2));
  Serial.print(",");
  Serial.print(analogRead(Soil_sensor_3));
  Serial.println();

  //Increase the sample number by 1 after each loop.
  sampleNumber++;

  //Control structure for LED lights
  //When the conditions are met the lights will turn on and stay on
  //When the conditions are NOT met the lights will turn off
  if (SM_1 < 250)
  {
    digitalWrite(RED_PIN,HIGH);
    delay(2000);
  }
  else
  {
     digitalWrite(RED_PIN,LOW);
  }
  
  if (SM_2 < 250)
  {
    digitalWrite(YLW_PIN,HIGH);
    delay(2000);
  }
  else
  {
     digitalWrite(YLW_PIN,LOW);
  }
  
  if (SM_3 < 250)
  {
    digitalWrite(BLUE_PIN,HIGH);
    delay(2000);
  }
  else
  {
     digitalWrite(BLUE_PIN,LOW);
  }

  //Recording frequency of 1Hz
  delay(1000);
}


